==> aspose_cad_cloud-24.5.0-py3-none-any.whl: asposecadcloud/models/__init__.py <==
#  coding: utf-8
#  ----------------------------------------------------------------------------
#  <copyright company="Aspose" file="__init__.py">
#    Copyright (c) 2018-2019 Aspose Pty Ltd. All rights reserved.
#  </copyright>
#  <summary>
#    Permission is hereby granted, free of charge, to any person obtaining a
#   copy  of this software and associated documentation files (the "Software"),
#   to deal  in the Software without restriction, including without limitation
#   the rights  to use, copy, modify, merge, publish, distribute, sublicense,
#   and/or sell  copies of the Software, and to permit persons to whom the
#   Software is  furnished to do so, subject to the following conditions:
#
#   The above copyright notice and this permission notice shall be included in
#   all  copies or substantial portions of the Software.
#
#   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#   FROM,  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#   DEALINGS IN THE SOFTWARE.
#  </summary>
#  ----------------------------------------------------------------------------

from __future__ import absolute_import

# import models into model package
from asposecadcloud.models.bitmap_compression import BitmapCompression
from asposecadcloud.models.cad_draw_type_mode import CadDrawTypeMode
from asposecadcloud.models.cad_response import CadResponse
from asposecadcloud.models.cf2_properties import Cf2Properties
from asposecadcloud.models.color import Color
from asposecadcloud.models.color_modes import ColorModes
from asposecadcloud.models.compression_method import CompressionMethod
from asposecadcloud.models.dgn_properties import DgnProperties
from asposecadcloud.models.disc_usage import DiscUsage
from asposecadcloud.models.drawing_options_base_dto import DrawingOptionsBaseDTO
from asposecadcloud.models.dwf_properties import DwfProperties
from asposecadcloud.models.dwg_properties import DwgProperties
from asposecadcloud.models.dxf_properties import DxfProperties
from asposecadcloud.models.error_details import ErrorDetails
from asposecadcloud.models.error_model import ErrorModel
from asposecadcloud.models.fbx_properties import FbxProperties
from asposecadcloud.models.file_versions import FileVersions
from asposecadcloud.models.files_list import FilesList
from asposecadcloud.models.files_upload_result import FilesUploadResult
from asposecadcloud.models.graphics_options import GraphicsOptions
from asposecadcloud.models.ifc_properties import IfcProperties
from asposecadcloud.models.igs_properties import IgsProperties
from asposecadcloud.models.interpolation_mode import InterpolationMode
from asposecadcloud.models.jpeg2000_codec import Jpeg2000Codec
from asposecadcloud.models.jpeg_compression_color_mode import JpegCompressionColorMode
from asposecadcloud.models.jpeg_compression_mode import JpegCompressionMode
from asposecadcloud.models.line_cap import LineCap
from asposecadcloud.models.obj_properties import ObjProperties
from asposecadcloud.models.object_exist import ObjectExist
from asposecadcloud.models.pdf_compliance import PdfCompliance
from asposecadcloud.models.pdf_digital_signature_details_core_dto import PdfDigitalSignatureDetailsCoreDTO
from asposecadcloud.models.pdf_digital_signature_hash_algorithm_core import PdfDigitalSignatureHashAlgorithmCore
from asposecadcloud.models.pdf_document_info import PdfDocumentInfo
from asposecadcloud.models.pdf_document_options_dto import PdfDocumentOptionsDTO
from asposecadcloud.models.pen_options import PenOptions
from asposecadcloud.models.plt_properties import PltProperties
from asposecadcloud.models.png_color_type import PngColorType
from asposecadcloud.models.png_filter_type import PngFilterType
from asposecadcloud.models.rd_optimizer_settings import RdOptimizerSettings
from asposecadcloud.models.resolution_setting import ResolutionSetting
from asposecadcloud.models.rotate_flip_type import RotateFlipType
from asposecadcloud.models.smoothing_mode import SmoothingMode
from asposecadcloud.models.stl_properties import StlProperties
from asposecadcloud.models.storage_exist import StorageExist
from asposecadcloud.models.storage_file import StorageFile
from asposecadcloud.models.stp_properties import StpProperties
from asposecadcloud.models.svg_color_mode import SvgColorMode
from asposecadcloud.models.text_rendering_hint import TextRenderingHint
from asposecadcloud.models.tiff_byte_order import TiffByteOrder
from asposecadcloud.models.tiff_compressions import TiffCompressions
from asposecadcloud.models.tiff_expected_format import TiffExpectedFormat
from asposecadcloud.models.tiff_photometrics import TiffPhotometrics
from asposecadcloud.models.unit_type import UnitType
from asposecadcloud.models.vector_rasterization_options_dto import VectorRasterizationOptionsDTO
from asposecadcloud.models.bmp_options_dto import BmpOptionsDTO
from asposecadcloud.models.cad_rasterization_options_dto import CadRasterizationOptionsDTO
from asposecadcloud.models.cgm_options_dto import CgmOptionsDTO
from asposecadcloud.models.dicom_options_dto import DicomOptionsDTO
from asposecadcloud.models.draco_options_dto import DracoOptionsDTO
from asposecadcloud.models.dwf_options_dto import DwfOptionsDTO
from asposecadcloud.models.dxf_options_dto import DxfOptionsDTO
from asposecadcloud.models.fbx_options_dto import FbxOptionsDTO
from asposecadcloud.models.file_version import FileVersion
from asposecadcloud.models.gif_options_dto import GifOptionsDTO
from asposecadcloud.models.glb_options_dto import GlbOptionsDTO
from asposecadcloud.models.gltf_options_dto import GltfOptionsDTO
from asposecadcloud.models.jpeg2000_options_dto import Jpeg2000OptionsDTO
from asposecadcloud.models.jpeg_options_dto import JpegOptionsDTO
from asposecadcloud.models.obj_options_dto import ObjOptionsDTO
from asposecadcloud.models.pdf_options_dto import PdfOptionsDTO
from asposecadcloud.models.png_options_dto import PngOptionsDTO
from asposecadcloud.models.psd_options_dto import PsdOptionsDTO
from asposecadcloud.models.stp_options_dto import StpOptionsDTO
from asposecadcloud.models.svg_options_dto import SvgOptionsDTO
from asposecadcloud.models.three_ds_options_dto import ThreeDSOptionsDTO
from asposecadcloud.models.tiff_options_dto import TiffOptionsDTO
from asposecadcloud.models.u3d_options_dto import U3dOptionsDTO
from asposecadcloud.models.webp_options_dto import WebpOptionsDTO
from asposecadcloud.models.wmf_options_dto import WmfOptionsDTO

==> aspose_cad_cloud-24.5.1-py3-none-any.whl: asposecadcloud/models/__init__.py <==
#  coding: utf-8
#  ----------------------------------------------------------------------------
#  <copyright company="Aspose" file="__init__.py">
#    Copyright (c) 2018-2019 Aspose Pty Ltd. All rights reserved.
#  </copyright>
#  <summary>
#    Permission is hereby granted, free of charge, to any person obtaining a
#   copy  of this software and associated documentation files (the "Software"),
#   to deal  in the Software without restriction, including without limitation
#   the rights  to use, copy, modify, merge, publish, distribute, sublicense,
#   and/or sell  copies of the Software, and to permit persons to whom the
#   Software is  furnished to do so, subject to the following conditions:
#
#   The above copyright notice and this permission notice shall be included in
#   all  copies or substantial portions of the Software.
#
#   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#   FROM,  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#   DEALINGS IN THE SOFTWARE.
#  </summary>
#  ----------------------------------------------------------------------------

from __future__ import absolute_import

# import models into model package
from asposecadcloud.models.bitmap_compression import BitmapCompression
from asposecadcloud.models.cad_draw_type_mode import CadDrawTypeMode
from asposecadcloud.models.cad_response import CadResponse
from asposecadcloud.models.cf2_properties import Cf2Properties
from asposecadcloud.models.color_dto import ColorDTO
from asposecadcloud.models.color_modes import ColorModes
from asposecadcloud.models.compression_method import CompressionMethod
from asposecadcloud.models.dgn_properties import DgnProperties
from asposecadcloud.models.disc_usage import DiscUsage
from asposecadcloud.models.drawing_options_base_dto import DrawingOptionsBaseDTO
from asposecadcloud.models.dwf_properties import DwfProperties
from asposecadcloud.models.dwg_properties import DwgProperties
from asposecadcloud.models.dxf_properties import DxfProperties
from asposecadcloud.models.error import Error
from asposecadcloud.models.error_details import ErrorDetails
from asposecadcloud.models.fbx_properties import FbxProperties
from asposecadcloud.models.file_versions import FileVersions
from asposecadcloud.models.files_list import FilesList
from asposecadcloud.models.files_upload_result import FilesUploadResult
from asposecadcloud.models.graphics_options import GraphicsOptions
from asposecadcloud.models.ifc_properties import IfcProperties
from asposecadcloud.models.igs_properties import IgsProperties
from asposecadcloud.models.interpolation_mode import InterpolationMode
from asposecadcloud.models.jpeg2000_codec import Jpeg2000Codec
from asposecadcloud.models.jpeg_compression_color_mode import JpegCompressionColorMode
from asposecadcloud.models.jpeg_compression_mode import JpegCompressionMode
from asposecadcloud.models.line_cap import LineCap
from asposecadcloud.models.obj_properties import ObjProperties
from asposecadcloud.models.object_exist import ObjectExist
from asposecadcloud.models.pdf_compliance import PdfCompliance
from asposecadcloud.models.pdf_digital_signature_details_core_dto import PdfDigitalSignatureDetailsCoreDTO
from asposecadcloud.models.pdf_digital_signature_hash_algorithm_core import PdfDigitalSignatureHashAlgorithmCore
from asposecadcloud.models.pdf_document_info import PdfDocumentInfo
from asposecadcloud.models.pdf_document_options_dto import PdfDocumentOptionsDTO
from asposecadcloud.models.pen_options import PenOptions
from asposecadcloud.models.plt_properties import PltProperties
from asposecadcloud.models.png_color_type import PngColorType
from asposecadcloud.models.png_filter_type import PngFilterType
from asposecadcloud.models.rd_optimizer_settings import RdOptimizerSettings
from asposecadcloud.models.resolution_setting import ResolutionSetting
from asposecadcloud.models.rotate_flip_type import RotateFlipType
from asposecadcloud.models.smoothing_mode import SmoothingMode
from asposecadcloud.models.stl_properties import StlProperties
from asposecadcloud.models.storage_exist import StorageExist
from asposecadcloud.models.storage_file import StorageFile
from asposecadcloud.models.stp_properties import StpProperties
from asposecadcloud.models.svg_color_mode import SvgColorMode
from asposecadcloud.models.text_rendering_hint import TextRenderingHint
from asposecadcloud.models.tiff_byte_order import TiffByteOrder
from asposecadcloud.models.tiff_compressions import TiffCompressions
from asposecadcloud.models.tiff_expected_format import TiffExpectedFormat
from asposecadcloud.models.tiff_photometrics import TiffPhotometrics
from asposecadcloud.models.unit_type import UnitType
from asposecadcloud.models.vector_rasterization_options_dto import VectorRasterizationOptionsDTO
from asposecadcloud.models.watermark_rgb import WatermarkRGB
from asposecadcloud.models.bmp_options_dto import BmpOptionsDTO
from asposecadcloud.models.cad_rasterization_options_dto import CadRasterizationOptionsDTO
from asposecadcloud.models.cgm_options_dto import CgmOptionsDTO
from asposecadcloud.models.dicom_options_dto import DicomOptionsDTO
from asposecadcloud.models.draco_options_dto import DracoOptionsDTO
from asposecadcloud.models.dwf_options_dto import DwfOptionsDTO
from asposecadcloud.models.dxf_options_dto import DxfOptionsDTO
from asposecadcloud.models.fbx_options_dto import FbxOptionsDTO
from asposecadcloud.models.file_version import FileVersion
from asposecadcloud.models.gif_options_dto import GifOptionsDTO
from asposecadcloud.models.glb_options_dto import GlbOptionsDTO
from asposecadcloud.models.gltf_options_dto import GltfOptionsDTO
from asposecadcloud.models.jpeg2000_options_dto import Jpeg2000OptionsDTO
from asposecadcloud.models.jpeg_options_dto import JpegOptionsDTO
from asposecadcloud.models.obj_options_dto import ObjOptionsDTO
from asposecadcloud.models.pdf_options_dto import PdfOptionsDTO
from asposecadcloud.models.png_options_dto import PngOptionsDTO
from asposecadcloud.models.psd_options_dto import PsdOptionsDTO
from asposecadcloud.models.stp_options_dto import StpOptionsDTO
from asposecadcloud.models.svg_options_dto import SvgOptionsDTO
from asposecadcloud.models.three_ds_options_dto import ThreeDSOptionsDTO
from asposecadcloud.models.tiff_options_dto import TiffOptionsDTO
from asposecadcloud.models.u3d_options_dto import U3dOptionsDTO
from asposecadcloud.models.webp_options_dto import WebpOptionsDTO
from asposecadcloud.models.wmf_options_dto import WmfOptionsDTO
